<?php

namespace Drupal\k8s\Form;

use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a form for deleting Cloud config entities.
 *
 * @ingroup k8s
 */
class PodDeleteForm extends K8sDeleteForm {

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $entity = $this->entity;

    $this->k8sService->setCloudContext($entity->getCloudContext());
    $result = $this->k8sService->deletePod($entity->getNamespace(), [
      'metadata' => [
        'name' => $entity->getName(),
      ],
    ]);
    if (!empty($result)) {
      $message = $this->t('The @type "@label" has been deleted.', [
        '@type'  => $entity->getEntityType()->getLabel(),
        '@label' => $entity->label(),
      ]);

      $entity->delete();
      $this->messenger->addMessage($message);
    }
    else {
      $message = $this->t('The @type "@label" couldn\'t delete.', [
        '@type'  => $entity->getEntityType()->getLabel(),
        '@label' => $entity->label(),
      ]);
      $this->messenger->addError($message);
    }

    $form_state->setRedirect('view.k8s_pod.list', ['cloud_context' => $entity->getCloudContext()]);
  }

}
