<?php

namespace Drupal\k8s\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Component\Serialization\Yaml;

/**
 * Form controller for the Namespace entity edit forms.
 *
 * @ingroup aws_cloud
 */
class PodEditForm extends K8sContentForm {

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $cloud_context = '') {
    $form = parent::buildForm($form, $form_state);

    $entity = $this->entity;
    $weight = -50;
    $form['pod'] = [
      '#type' => 'details',
      '#title' => $this->t('Pod'),
      '#open' => TRUE,
      '#weight' => $weight++,
    ];

    $form['pod']['name'] = [
      '#type'          => 'item',
      '#title'         => $this->getItemTitle($this->t('Name')),
      '#markup'        => $entity->getName(),
      '#weight'        => $weight++,
    ];

    $form['pod']['namespace'] = [
      '#type'          => 'item',
      '#title'         => $this->getItemTitle($this->t('Namespace')),
      '#markup'        => $entity->getNamespace(),
      '#weight'        => $weight++,
    ];

    $form['pod']['detail'] = $form['detail'];
    unset($form['detail']);

    $this->addOthersFieldset($form, $weight++, $cloud_context);

    $form['actions'] = $this->actions($form, $form_state, $cloud_context);
    $form['actions']['#weight'] = $weight++;

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    // Call copyFormItemValues() to ensure the form array is intact.
    $this->copyFormItemValues($form);

    $this->trimTextfields($form, $form_state);

    $entity = $this->entity;

    $this->k8sService->setCloudContext($entity->getCloudContext());
    $result = $this->k8sService->updatePod(
      $entity->getNamespace(),
      Yaml::decode($entity->getDetail())
    );

    if (!empty($result) && $entity->save()) {

      // Update the pod.
      $this->k8sService->updatePods([
        'metadata.name' => $entity->getName(),
      ], FALSE);

      $message = $this->t('The @label "%label" has been saved.', [
        '@label' => $entity->getEntityType()->getLabel(),
        '%label' => $entity->label(),
      ]);

      $this->messenger->addMessage($message);
    }
    else {
      $this->messenger->addError($this->t('Unable to update @label.', [
        '@label' => $entity->getEntityType()->getLabel(),
      ]));
    }

    $form_state->setRedirect('view.k8s_pod.list', [
      'cloud_context' => $entity->getCloudContext(),
    ]);
  }

}
