<?php

namespace Drupal\k8s\Service;

use Maclof\Kubernetes\Client;
use Maclof\Kubernetes\Exceptions\BadRequestException;
use GuzzleHttp\Client as GuzzleClient;

use Drupal\Core\Messenger\Messenger;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\StringTranslation\TranslationInterface;

/**
 * K8s client.
 */
class K8sClient extends Client {

  use StringTranslationTrait;

  /**
   * The Messenger service.
   *
   * @var \Drupal\Core\Messenger\Messenger
   */
  private $messenger;

  /**
   * The constructor.
   *
   * @param array $options
   *   Options.
   * @param \GuzzleHttp\Client $guzzle_client
   *   The guzzle client.
   * @param \Drupal\Core\Messenger\Messenger $messenger
   *   The messenger object.
   * @param \Drupal\Core\StringTranslation\TranslationInterface $string_translation
   *   The string translation service.
   */
  public function __construct(
    array $options = [],
    GuzzleClient $guzzle_client = NULL,
    Messenger $messenger,
    TranslationInterface $string_translation
  ) {
    parent::__construct($options, $guzzle_client);

    $this->messenger = $messenger;

    // Setup the $this->t()
    $this->stringTranslation = $string_translation;
  }

  /**
   * {@inheritdoc}
   */
  public function sendRequest(
    $method,
    $uri,
    $query = [],
    $body = [],
    $namespace = TRUE,
    $apiVersion = NULL
  ) {
    try {
      return parent::sendRequest(
        $method,
        $uri,
        $query,
        $body,
        $namespace,
        $apiVersion
      );
    }
    catch (BadRequestException $e) {
      $error_info = json_decode($e->getMessage(), TRUE);

      $this->messenger->addError($this->t(
        'Status Code: @status_code', ['@status_code' => $error_info['code']]
      ));

      $this->messenger->addError($this->t(
        'Error reason: @error_reason', ['@error_reason' => $error_info['reason']]
      ));

      $this->messenger->addError($this->t(
        'Message: @msg', ['@msg' => $error_info['message']]
      ));
    }
    catch (\Exception $e) {
      $this->messenger->addError($e->getMessage());
    }

    return NULL;
  }

}
