<?php

namespace Drupal\k8s\Service;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityFieldManagerInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\core\Field\FieldTypePluginManagerInterface;
use Drupal\Core\Lock\LockBackendInterface;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\Core\Messenger\Messenger;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\StringTranslation\TranslationInterface;

use Drupal\cloud\Plugin\CloudConfigPluginManagerInterface;

/**
 * K8sServiceMock service interacts with the K8s API.
 */
class K8sServiceMock extends K8sService {

  /**
   * The config.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $config;

  /**
   * Constructs a new K8sService object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   An entity type manager instance.
   * @param \Drupal\Core\Logger\LoggerChannelFactoryInterface $logger_factory
   *   A logger instance.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   A configuration factory.
   * @param \Drupal\Core\Messenger\Messenger $messenger
   *   The messenger service.
   * @param \Drupal\Core\StringTranslation\TranslationInterface $string_translation
   *   The string translation service.
   * @param \Drupal\Core\Session\AccountInterface $current_user
   *   The current user.
   * @param \Drupal\cloud\Plugin\CloudConfigPluginManagerInterface $cloud_config_plugin_manager
   *   The cloud config plugin manager.
   * @param \Drupal\core\Field\FieldTypePluginManagerInterface $field_type_plugin_manager
   *   The field type plugin manager.
   * @param \Drupal\Core\Entity\EntityFieldManagerInterface $entity_field_manager
   *   The entity field manager.
   * @param \Drupal\Core\Lock\LockBackendInterface $lock
   *   The lock interface.
   */
  public function __construct(
    EntityTypeManagerInterface $entity_type_manager,
    LoggerChannelFactoryInterface $logger_factory,
    ConfigFactoryInterface $config_factory,
    Messenger $messenger,
    TranslationInterface $string_translation,
    AccountInterface $current_user,
    CloudConfigPluginManagerInterface $cloud_config_plugin_manager,
    FieldTypePluginManagerInterface $field_type_plugin_manager,
    EntityFieldManagerInterface $entity_field_manager,
    LockBackendInterface $lock
  ) {
    parent::__construct(
      $entity_type_manager,
      $logger_factory,
      $config_factory,
      $messenger,
      $string_translation,
      $current_user,
      $cloud_config_plugin_manager,
      $field_type_plugin_manager,
      $entity_field_manager,
      $lock
    );

    $this->config = $config_factory->get('k8s.settings');
  }

  /**
   * {@inheritdoc}
   */
  public function getPods(array $params = []) {
    return json_decode($this->config->get('k8s_mock_data'), TRUE)['getPods'];
  }

  /**
   * {@inheritdoc}
   */
  public function getNodes(array $params = []) {
    return json_decode($this->config->get('k8s_mock_data'), TRUE)['getNodes'];
  }

  /**
   * {@inheritdoc}
   */
  public function getNamespaces(array $params = []) {
    return json_decode($this->config->get('k8s_mock_data'), TRUE)['getNamespaces'];
  }

  /**
   * {@inheritdoc}
   */
  public function createNamespace(array $params = []) {
    return json_decode($this->config->get('k8s_mock_data'), TRUE)['createNamespace'];
  }

  /**
   * {@inheritdoc}
   */
  public function updateNamespace(array $params = []) {
    return json_decode($this->config->get('k8s_mock_data'), TRUE)['updateNamespace'];
  }

  /**
   * {@inheritdoc}
   */
  public function deleteNamespace(array $params = []) {
    return json_decode($this->config->get('k8s_mock_data'), TRUE)['deleteNamespace'];
  }

  /**
   * {@inheritdoc}
   */
  public function createPod($namespace, array $params = []) {
    return json_decode($this->config->get('k8s_mock_data'), TRUE)['createPod'];
  }

  /**
   * {@inheritdoc}
   */
  public function updatePod($namespace, array $params = []) {
    return json_decode($this->config->get('k8s_mock_data'), TRUE)['updatePod'];
  }

  /**
   * {@inheritdoc}
   */
  public function deletePod($namespace, array $params = []) {
    return json_decode($this->config->get('k8s_mock_data'), TRUE)['deletePod'];
  }

}
