<?php

namespace Drupal\Tests\k8s\Functional\Config;

use Drupal\Tests\k8s\Functional\K8sTestCase;

/**
 * Tests Cloud Config.
 *
 * @group k8s
 */
class K8sCloudConfigTest extends K8sTestCase {

  const K8S_CLOUD_CONFIG_REPEAT_COUNT = 3;

  /**
   * {@inheritdoc}
   */
  protected function getPermissions() {
    return [
      'administer cloud config entities',
      'view all cloud config entities',
      'add cloud config entities',
      'edit cloud config entities',
      'edit own cloud config entities',
      'delete cloud config entities',
      'delete own cloud config entities',
      'view unpublished cloud config entities',
      'view own unpublished cloud config entities',
      'view published cloud config entities',
      'view own published cloud config entities',
      'access dashboard',
      'view cloud config admin list',
      'administer k8s',
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function createCloudContext($bundle_type = 'k8s') {
  }

  /**
   * Tests CRUD for Cloud config information.
   */
  public function testCloudConfig() {

    // List k8s.
    $this->drupalGet('/admin/structure/cloud_config');
    $this->assertResponse(200, t('HTTP 200: List | K8s'));
    $this->assertNoText(t('Notice'), t('Make sure w/o Notice'));
    $this->assertNoText(t('Warning'), t('Make sure w/o Warnings'));

    // Add a new Config information.
    $add = $this->createCloudConfigTestFormData(self::K8S_CLOUD_CONFIG_REPEAT_COUNT);
    for ($i = 0; $i < self::K8S_CLOUD_CONFIG_REPEAT_COUNT; $i++) {
      unset($add[$i]['cloud_context']);
      $this->drupalGet('/admin/structure/cloud_config/add');
      $this->assertResponse(200, t('HTTP 200: Add | K8s Cloud Config Form'));
      $this->assertNoText(t('Notice'), t('Make sure w/o Notice'));
      $this->assertNoText(t('Warning'), t('Make sure w/o Warnings'));

      $this->drupalPostForm('/admin/structure/cloud_config/add',
        $add[$i],
        t('Save')
      );

      $this->assertResponse(200, t('HTTP 200: Saved | K8s Cloud Config Form'));
      $this->assertNoText(t('Notice'), t('Make sure w/o Notice'));
      $this->assertNoText(t('Warning'), t('Make sure w/o Warnings'));
      $this->assertText(t('Created the @label Cloud config.',
        ['@label' => $add[$i]['name[0][value]']]
      ));

      // Make sure listing for '/admin/structure/cloud_config'.
      $this->drupalGet('/admin/structure/cloud_config');
      $this->assertResponse(200, t('HTTP 200: List | K8s'));
      $this->assertNoText(t('Notice'), t('Make sure w/o Notice'));
      $this->assertNoText(t('Warning'), t('Make sure w/o Warnings'));
      $this->assertLink($add[$i]['name[0][value]']);

      // Make sure listing for '/clouds'.
      $this->drupalGet('/clouds');
      $this->assertResponse(200, t('HTTP 200: List | K8s'));
      $this->assertNoText(t('Notice'), t('Make sure w/o Notice'));
      $this->assertNoText(t('Warning'), t('Make sure w/o Warnings'));
      $this->assertLink($add[$i]['name[0][value]']);

      // Make sure listing for '/admin/config/services/cloud/k8s'.
      $this->drupalGet('/admin/config/services/cloud/k8s');
      $this->assertResponse(200, t('HTTP 200: List | K8s'));
      $this->assertNoText(t('Notice'), t('Make sure w/o Notice'));
      $this->assertNoText(t('Warning'), t('Make sure w/o Warnings'));
      $this->assertLink($add[$i]['name[0][value]']);
    }

    // Edit Config case.
    $edit = $this->createCloudConfigTestFormData(self::K8S_CLOUD_CONFIG_REPEAT_COUNT);
    for ($i = 0; $i < self::K8S_CLOUD_CONFIG_REPEAT_COUNT; $i++) {
      $num = $i + 1;

      unset($edit[$i]['cloud_context']);

      $this->drupalPostForm("/admin/structure/cloud_config/${num}/edit",
        $edit[$i],
        t('Save')
      );
      $this->assertResponse(200, t('HTTP 200: Edit | K8s Form'));
      $this->assertNoText(t('Notice'), t('Make sure w/o Notice'));
      $this->assertNoText(t('Warning'), t('Make sure w/o Warnings'));

      // Make sure listing for '/admin/structure/cloud_config'.
      $this->drupalGet('/admin/structure/cloud_config');
      $this->assertResponse(200, t('HTTP 200: List | K8s'));
      $this->assertNoText(t('Notice'), t('Make sure w/o Notice'));
      $this->assertNoText(t('Warning'), t('Make sure w/o Warnings'));
      $this->assertLink($edit[$i]['name[0][value]']);

      // Make sure listing for '/clouds'.
      $this->drupalGet('/clouds');
      $this->assertResponse(200, t('HTTP 200: List | K8s'));
      $this->assertNoText(t('Notice'), t('Make sure w/o Notice'));
      $this->assertNoText(t('Warning'), t('Make sure w/o Warnings'));
      $this->assertLink($edit[$i]['name[0][value]']);

      // Make sure listing for '/admin/config/services/cloud/k8s'.
      $this->drupalGet('/admin/config/services/cloud/k8s');
      $this->assertResponse(200, t('HTTP 200: List | K8s'));
      $this->assertNoText(t('Notice'), t('Make sure w/o Notice'));
      $this->assertNoText(t('Warning'), t('Make sure w/o Warnings'));
      $this->assertLink($edit[$i]['name[0][value]']);
    }

    // Delete Config Items.
    for ($i = 0; $i < self::K8S_CLOUD_CONFIG_REPEAT_COUNT; $i++) {
      $num = $i + 1;

      $this->drupalPostForm("/admin/structure/cloud_config/${num}/delete",
        [],
        t('Delete')
      );

      $this->assertResponse(200, t('HTTP 200: Delete | K8s'));
      $this->assertNoText(t('Notice'), t('Make sure w/o Notice'));
      $this->assertNoText(t('Warning'), t('Make sure w/o Warnings'));
      $this->assertText(t('The cloud config @label has been deleted.',
        ['@label' => $edit[$i]['name[0][value]']]
      ));

      // Because $cloud_context has been deleted.
      // Make sure listing.
      for ($k = 0; $k < $num; $k++) {

        // Make sure listing for '/admin/structure/cloud_config'.
        $this->drupalGet('/admin/structure/cloud_config');
        $this->assertResponse(200, t('HTTP 200: List | K8s'));
        $this->assertNoText(t('Notice'), t('Make sure w/o Notice'));
        $this->assertNoText(t('Warning'), t('Make sure w/o Warnings'));
        $this->assertNoLink($edit[$k]['name[0][value]']);

        // Make sure listing for '/clouds'.
        $this->drupalGet('/clouds');
        $this->assertResponse(200, t('HTTP 200: List | K8s'));
        $this->assertNoText(t('Notice'), t('Make sure w/o Notice'));
        $this->assertNoText(t('Warning'), t('Make sure w/o Warnings'));
        $this->assertNoLink($edit[$k]['name[0][value]']);

        // Make sure listing for '/admin/config/services/cloud/k8s'.
        $this->drupalGet('/admin/config/services/cloud/k8s');
        $this->assertResponse(200, t('HTTP 200: List | K8s'));
        $this->assertNoText(t('Notice'), t('Make sure w/o Notice'));
        $this->assertNoText(t('Warning'), t('Make sure w/o Warnings'));
        $this->assertNoLink($edit[$k]['name[0][value]']);
      }
    }
  }

}
