<?php

namespace Drupal\Tests\k8s\Functional;

/**
 * Tests K8s pod.
 *
 * @group k8s
 */
class PodTest extends K8sTestCase {

  const K8S_POD_REPEAT_COUNT = 3;

  /**
   * {@inheritdoc}
   */
  protected function getPermissions() {
    return [
      'list k8s pod',
      'view k8s pod',
      'edit k8s pod',
      'add k8s pod',
      'delete k8s pod',
    ];
  }

  /**
   * Tests CRUD for Pod.
   */
  public function testPod() {

    $cloud_context = $this->cloudContext;

    // List Pod for K8s.
    $this->drupalGet("/clouds/k8s/$cloud_context/pod");
    $this->assertResponse(200);

    // Add a new Pod.
    $add = $this->createPodTestFormData(self::K8S_POD_REPEAT_COUNT);
    for ($i = 0; $i < self::K8S_POD_REPEAT_COUNT; $i++) {
      $this->reloadMockData();

      $this->addPodMockData($add[$i]);

      $num = $i + 1;
      $this->drupalPostForm(
        "/clouds/k8s/$cloud_context/pod/add",
        $add[$i]['post_data'],
        t('Save')
      );
      $this->assertResponse(200);
      $this->assertText(t('The Kubernetes Pod "@name" has been created.', ['@name' => $add[$i]['name']]));

      // Make sure listing.
      $this->drupalGet("/clouds/k8s/$cloud_context/pod");
      $this->assertResponse(200);
      $this->assertText($add[$i]['name']);
    }

    // Edit a Pod.
    $edit = $this->createPodTestFormData(self::K8S_POD_REPEAT_COUNT);
    for ($i = 0; $i < self::K8S_POD_REPEAT_COUNT; $i++) {
      $num = $i + 1;
      $this->updatePodMockData($edit[$i]);

      unset($edit[$i]['post_data']['namespace']);
      $this->drupalPostForm(
        "/clouds/k8s/$cloud_context/pod/$num/edit",
        $edit[$i]['post_data'],
        t('Save')
      );
      $this->assertResponse(200);
      $this->assertText(t(
        'The Kubernetes Pod "@name" has been saved.',
        ['@name' => $add[$i]['name']]
      ));
    }

    // Delete Pod.
    for ($i = 0; $i < self::K8S_POD_REPEAT_COUNT; $i++) {
      $num = $i + 1;

      $this->deletePodMockData($add[$i]);

      $this->drupalPostForm(
        "/clouds/k8s/$cloud_context/pod/$num/delete",
        [],
        t('Delete')
      );
      $this->assertResponse(200);
      $this->assertText(t(
        'The Kubernetes Pod "@name" has been deleted.',
        ['@name' => $add[$i]['name']]
      ));

      // Make sure listing.
      $this->drupalGet("/clouds/k8s/$cloud_context/pod");
      $this->assertResponse(200);
      $this->assertNoText($add[$i]['name']);
    }
  }

  /**
   * Tests deleting pods with bulk operation.
   */
  public function testPodBulk() {
    $cloud_context = $this->cloudContext;
    for ($i = 0; $i < self::K8S_POD_REPEAT_COUNT; $i++) {
      // Create Pods.
      $pods = $this->createPodsRandomTestFormData();
      $entities = [];
      foreach ($pods as $pod) {
        $entities[] = $this->createPodTestEntity($pod);
      }
      $this->deletePodMockData($pods[0]);
      $this->doTestEntityBulk('pod', $entities);
    }
  }

}
