<?php

namespace Drupal\Tests\k8s\Traits;

use Drupal\Component\Utility\Random;

/**
 * The trait creating mock data for k8s testing.
 */
trait K8sTestMockTrait {

  /**
   * Update getNodes in mock data.
   *
   * @param array $data
   *   The mock data.
   */
  protected function updateNodesMockData(array $data) {
    $mock_data = $this->getMockDataFromConfig();

    $random = new Random();

    $nodes = [];
    foreach ($data as $node_data) {
      $nodes[] = [
        'metadata' => [
          'name' => $node_data['name'],
          'creationTimestamp' => date('Y/m/d H:i:s'),
          'labels' => [
            'label1' => 'label-' . $random->string(8, TRUE),
          ],
          'annotations' => [
            'annotation1' => 'annotation-' . $random->string(8, TRUE),
          ],
        ],
        'spec' => [
          'podCIDR' => $random->name(8, TRUE),
          'providerID' => $random->name(8, TRUE),
          'unschedulable' => FALSE,

        ],
        'status' => [
          'conditions' => [
            [
              'type' => 'Ready',
            ],
          ],
          'addresses' => [
            [
              'type' => 'type-' . $random->name(8, TRUE),
              'address' => implode(
                '.',
                [rand(0, 254), rand(0, 255), rand(0, 255), rand(1, 255)]
              ),
            ],
          ],
          'nodeInfo' => [
            'machineID' => 'machine-' . $random->name(16, TRUE),
            'systemUUID' => 'system-' . $random->name(16, TRUE),
            'bootID' => 'boot-' . $random->name(16, TRUE),
            'kernelVersion' => 'kernel-' . $random->name(8, TRUE),
            'osImage' => 'os-' . $random->name(8, TRUE),
            'containerRuntimeVersion' => 'version-' . $random->name(8, TRUE),
            'kubeletVersion' => 'kubelet-' . $random->name(8, TRUE),
            'kubeProxyVersion' => 'kubeProxy-' . $random->name(8, TRUE),
            'operatingSystem' => 'linux',
            'architecture' => 'arc-' . $random->name(8, TRUE),
          ],
        ],
      ];
    }
    $mock_data['getNodes'] = $nodes;
    $this->updateMockDataToConfig($mock_data);
  }

  /**
   * Update createNamespace in mock data.
   *
   * @param array $namespace
   *   The namespace mock data.
   */
  protected function addNamespaceMockData(array $namespace) {
    $mock_data = $this->getMockDataFromConfig();

    $random = new Random();
    $create_namespace = [
      'metadata' => [
        'name' => $namespace['name'],
        'creationTimestamp' => date('Y/m/d H:i:s'),
      ],
      'status' => [
        'phase' => 'Active',
      ],
    ];
    $mock_data['createNamespace'] = $create_namespace;
    $this->updateMockDataToConfig($mock_data);
  }

  /**
   * Update updateNamespace in mock data.
   *
   * @param array $namespace
   *   The namespace mock data.
   */
  protected function updateNamespaceMockData(array $namespace) {
    $mock_data = $this->getMockDataFromConfig();

    $random = new Random();
    $update_namespace = [
      'metadata' => [
        'name' => $namespace['name'],
      ],
      'status' => [
        'phase' => 'Active',
      ],
    ];
    $mock_data['updateNamespace'] = $update_namespace;
    $this->updateMockDataToConfig($mock_data);
  }

  /**
   * Update deleteNamespace in mock data.
   *
   * @param array $namespace
   *   The namespace mock data.
   */
  protected function deleteNamespaceMockData(array $namespace) {
    $mock_data = $this->getMockDataFromConfig();

    $random = new Random();
    $delete_namespace = [
      'metadata' => [
        'name' => $namespace['name'],
      ],
      'status' => [
        'phase' => 'Active',
      ],
    ];
    $mock_data['deleteNamespace'] = $delete_namespace;
    $this->updateMockDataToConfig($mock_data);
  }

  /**
   * Update deletePod in mock data.
   *
   * @param array $pod
   *   The pod mock data.
   */
  protected function deletePodMockData(array $pod) {
    $mock_data = $this->getMockDataFromConfig();

    $random = new Random();
    $delete_pod = [
      'metadata' => [
        'name' => $pod['name'],
      ],
      'status' => [
        'phase' => 'Active',
      ],
    ];
    $mock_data['deletePod'] = $delete_pod;
    $this->updateMockDataToConfig($mock_data);
  }

  /**
   * Update createPod in mock data.
   *
   * @param array $pod
   *   The pod mock data.
   */
  protected function addPodMockData(array $pod) {
    $mock_data = $this->getMockDataFromConfig();

    $random = new Random();
    $create_pod = [
      'metadata' => [
        'name' => $pod['name'],
        'namespace' => $pod['post_data']['namespace'],
        'creationTimestamp' => date('Y/m/d H:i:s'),
      ],
      'status' => [
        'phase' => 'Active',
      ],
    ];
    $mock_data['createPod'] = $create_pod;

    $get_namespaces[] = [
      'metadata' => [
        'name' => $pod['post_data']['namespace'],
        'creationTimestamp' => date('Y/m/d H:i:s'),
      ],
    ];
    $mock_data['getNamespaces'] = $get_namespaces;

    $get_pods = [];
    $get_pods[] = $create_pod;
    $get_pods[0]['spec'] = [
      'containers' => [],
      'nodeName' => 'node-name' . $random->name(8, TRUE),
    ];
    $get_pods[0]['status'] = [
      'containerStatuses' => [],
      'phase' => 'Active',
      'qosClass' => 'BestEffort',
      'podIP' => '10.0.0.1',
    ];
    $mock_data['getPods'] = $get_pods;

    $this->updateMockDataToConfig($mock_data);
  }

  /**
   * Update updatePod in mock data.
   *
   * @param array $pod
   *   The pod mock data.
   */
  protected function updatePodMockData(array $pod) {
    $mock_data = $this->getMockDataFromConfig();

    $random = new Random();
    $update_pod = [
      'metadata' => [
        'name' => $pod['name'],
        'namespace' => $pod['post_data']['namespace'],
        'creationTimestamp' => date('Y/m/d H:i:s'),
      ],
      'status' => [
        'phase' => 'Active',
      ],
    ];
    $mock_data['updatePod'] = $update_pod;

    $get_pods = [];
    $get_pods[] = $update_pod;
    $get_pods[0]['spec'] = [
      'containers' => [],
      'nodeName' => 'node-name' . $random->name(8, TRUE),
    ];
    $get_pods[0]['status'] = [
      'containerStatuses' => [],
      'phase' => 'Active',
      'qosClass' => 'BestEffort',
      'podIP' => '10.0.0.1',
    ];
    $mock_data['getPods'] = $get_pods;

    $this->updateMockDataToConfig($mock_data);
  }

}
